@@ -31,10 +31,10 @@ import (
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/wait"
 
-	"github.com/openshift/cloud-credential-operator/pkg/controller/credentialsrequest/actuator"
-	actuatoriface "github.com/openshift/cloud-credential-operator/pkg/controller/credentialsrequest/actuator"
-	annotatorconst "github.com/openshift/cloud-credential-operator/pkg/controller/secretannotator/constants"
-	"github.com/openshift/cloud-credential-operator/pkg/controller/utils"
+	"github.com/openshift/cloud-credential-operator/pkg/operator/credentialsrequest/actuator"
+	actuatoriface "github.com/openshift/cloud-credential-operator/pkg/operator/credentialsrequest/actuator"
+	annotatorconst "github.com/openshift/cloud-credential-operator/pkg/operator/secretannotator/constants"
+	"github.com/openshift/cloud-credential-operator/pkg/operator/utils"
 	log "github.com/sirupsen/logrus"
 	"sigs.k8s.io/controller-runtime/pkg/client"
 
@@ -281,6 +281,9 @@ func loadAzureInfrastructureResourceGroups(c client.Client, logger log.FieldLogg
 	}
 
 	resourceGroups := []string{infra.Status.PlatformStatus.Azure.ResourceGroupName}
+	if infra.Status.PlatformStatus.Azure.NetworkResourceGroupName != "" && infra.Status.PlatformStatus.Azure.NetworkResourceGroupName != infra.Status.PlatformStatus.Azure.ResourceGroupName {
+		resourceGroups = append(resourceGroups, infra.Status.PlatformStatus.Azure.NetworkResourceGroupName)
+	}
 
 	dns := &configv1.DNS{}
 	err = c.Get(context.Background(), types.NamespacedName{Name: "cluster"}, dns)
